==> plantuml-libs-7.1.0.tgz: package/distribution/fontawesome-6/Solid/WheatAwnCircleExclamation.md <==
# WheatAwnCircleExclamation


```text
fontawesome-6/Solid/WheatAwnCircleExclamation
```

```text
include('fontawesome-6/Solid/WheatAwnCircleExclamation')
```



| Illustration | WheatAwnCircleExclamation |
| :---: | :---: |
| ![illustration for Illustration](../../fontawesome-6/Solid/WheatAwnCircleExclamation.png) | ![illustration for WheatAwnCircleExclamation](../../fontawesome-6/Solid/WheatAwnCircleExclamation.Local.png) |




## WheatAwnCircleExclamation

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('fontawesome-6/bootstrap')

' loads the Item which embeds the element WheatAwnCircleExclamation
include('fontawesome-6/Solid/WheatAwnCircleExclamation')

' renders the element
WheatAwnCircleExclamation('WheatAwnCircleExclamation', 'Wheat Awn Circle Exclamation', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('fontawesome-6/bootstrap')

' loads the Item which embeds the element WheatAwnCircleExclamation
include('fontawesome-6/Solid/WheatAwnCircleExclamation')

' renders the element
WheatAwnCircleExclamation('WheatAwnCircleExclamation', 'Wheat Awn Circle Exclamation', 'an optional tech label')
@enduml
```

==> plantuml-libs-9.1.0.tgz: package/distribution/fontawesome-6/Solid/WheatAwnCircleExclamation.md <==
# WheatAwnCircleExclamation


```text
fontawesome-6/Solid/WheatAwnCircleExclamation
```

```text
include('fontawesome-6/Solid/WheatAwnCircleExclamation')
```



| Illustration | WheatAwnCircleExclamation |
| :---: | :---: |
| ![illustration for Illustration](../../fontawesome-6/Solid/WheatAwnCircleExclamation.png) | ![illustration for WheatAwnCircleExclamation](../../fontawesome-6/Solid/WheatAwnCircleExclamation.Local.png) |




## WheatAwnCircleExclamation

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('fontawesome-6/bootstrap')

' loads the Item which embeds the element WheatAwnCircleExclamation
include('fontawesome-6/Solid/WheatAwnCircleExclamation')

' renders the element
WheatAwnCircleExclamation('WheatAwnCircleExclamation', 'Wheat Awn Circle Exclamation', 'an optional tech label', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('fontawesome-6/bootstrap')

' loads the Item which embeds the element WheatAwnCircleExclamation
include('fontawesome-6/Solid/WheatAwnCircleExclamation')

' renders the element
WheatAwnCircleExclamation('WheatAwnCircleExclamation', 'Wheat Awn Circle Exclamation', 'an optional tech label', 'an optional description')
@enduml
```
